from setuptools import setup

setup(
    name="sudeep",
    version="0.1.0",
    packages=["sudeep"],
    url="https://github.com/amalrajan/sudeep",
    license="MIT",
    author="Amal Rajan",
    author_email="amalrajan@outlook.com",
    description="About Sudeep",
    install_requires=[
        # List your package dependencies here
    ],
)
